@@ -2,9 +2,9 @@
 """
     pip_services3_commons.reflect.PropertyReflector
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    
+
     Property reflector implementation
-    
+
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
@@ -22,7 +22,7 @@ class PropertyReflector:
     this PropertyReflector treats all property names as case insensitive.
 
     Example:
-    
+
     .. code-block:: python
 
         myObj = MyObject()
@@ -39,7 +39,8 @@ class PropertyReflector:
         if callable(property):
             return False
 
-        if name.startswith("_"):
+        # if magic method or base abstract class property
+        if name.startswith("__") and name.endswith('__') or name == '_abc_impl':
             return False
 
         return True
@@ -79,10 +80,11 @@ class PropertyReflector:
             if property_name.lower() != name:
                 continue
 
-            property = getattr(obj, property_name)
+            if hasattr(obj, property_name):
+                property = getattr(obj, property_name, None)
 
-            if PropertyReflector._is_property(property, property_name):
-                return True
+                if PropertyReflector._is_property(property, property_name):
+                    return True
 
         return False
 
@@ -109,10 +111,11 @@ class PropertyReflector:
                 if property_name.lower() != name:
                     continue
 
-                property = getattr(obj, property_name)
+                if hasattr(obj, property_name):
+                    property = getattr(obj, property_name, None)
 
-                if PropertyReflector._is_property(property, property_name):
-                    return property
+                    if PropertyReflector._is_property(property, property_name):
+                        return property
         except:
             pass
 
@@ -131,10 +134,11 @@ class PropertyReflector:
 
         for property_name in dir(obj):
 
-            property = getattr(obj, property_name)
+            if hasattr(obj, property_name):
+                property = getattr(obj, property_name, None)
 
-            if PropertyReflector._is_property(property, property_name):
-                property_names.append(property_name)
+                if PropertyReflector._is_property(property, property_name):
+                    property_names.append(property_name)
 
         return property_names
 
@@ -151,10 +155,20 @@ class PropertyReflector:
 
         for property_name in dir(obj):
 
-            property = getattr(obj, property_name)
+            if hasattr(obj, property_name):
+                property = getattr(obj, property_name, None)
 
-            if PropertyReflector._is_property(property, property_name):
-                properties[property_name] = property
+                if PropertyReflector._is_property(property, property_name):
+
+                    # Prepare private fields
+                    if property_name.startswith('_') and len(property_name.split('__')) > 1:
+                        property_name = '__' + property_name.split('__')[-1]
+
+                    # Prepare protected fields
+                    elif property_name.startswith('_'):
+                        property_name = property_name[1:]
+
+                    properties[property_name] = property
 
         return properties
 
@@ -184,10 +198,11 @@ class PropertyReflector:
                 if property_name.lower() != name:
                     continue
 
-                property = getattr(obj, property_name)
+                if hasattr(obj, property_name):
+                    property = getattr(obj, property_name, None)
 
-                if PropertyReflector._is_property(property, property_name):
-                    setattr(obj, property_name, value)
+                    if PropertyReflector._is_property(property, property_name):
+                        setattr(obj, property_name, value)
         except:
             pass
 
