@@ -10,7 +10,7 @@
 """
 from typing import Any
 
-from pip_services3_commons.convert import TypeCode, TypeConverter, DateTimeConverter
+from ..convert import TypeCode, TypeConverter, DateTimeConverter
 
 
 class TypeMatcher:
@@ -62,7 +62,7 @@ class TypeMatcher:
         if isinstance(expected_type, type):
             return issubclass(type(actual_value), expected_type)
 
-        if isinstance(expected_type, int):
+        if isinstance(expected_type, TypeCode):
             if expected_type == actual_type:
                 return True
 
@@ -88,6 +88,8 @@ class TypeMatcher:
                     and DateTimeConverter.to_nullable_datetime(actual_value) is not None):
                 return True
 
+            return False
+
         if isinstance(expected_type, str):
             return TypeMatcher.match_type_by_name(expected_type, actual_type, actual_value)
 
