@@ -8,10 +8,9 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
-from typing import List, Sequence, Any
-
-from pip_services3_commons.validate import Schema
+from typing import List, Any, Tuple
 
+from ..validate import Schema
 from .IValidationRule import IValidationRule
 from .ValidationResult import ValidationResult
 from .ValidationResultType import ValidationResultType
@@ -32,15 +31,14 @@ class OnlyOneExistRule(IValidationRule):
         schema.validate({ field1: 1 })                  # Result: no errors
         schema.validate({ })                            # Result: only one of properties field1, field2 must exist
     """
-    __properties: Sequence[str] = None
 
-    def __init__(self, *properties):
+    def __init__(self, *properties: str):
         """
         Creates a new validation rule and sets its values
 
         :param properties: a list of property names where at only one property must exist
         """
-        self.__properties = properties
+        self.__properties: Tuple[str] = properties
 
     def validate(self, path: str, schema: Schema, value: Any, results: List[ValidationResult]):
         """
@@ -54,12 +52,12 @@ class OnlyOneExistRule(IValidationRule):
 
         :param results: a list with validation results to add new results.
         """
-        name = path if not (path is None) else "args"
-        found = []
+        name = path or "args"
+        found: List[str] = []
 
         for prop in self.__properties:
             property_value = ObjectReader.get_property(value, prop)
-            if not (property_value is None):
+            if property_value:
                 found.append(prop)
 
         if len(found) == 0:
@@ -81,6 +79,6 @@ class OnlyOneExistRule(IValidationRule):
                     "VALUE_ONLY_ONE",
                     name + " must have only one property from " + str(self.__properties),
                     self.__properties,
-                    found
+                    None
                 )
             )
